# Hi, I'm Arslan 👋✨

<img src="https://user-images.githubusercontent.com/53117861/88454705-c4c0cd80-ce8a-11ea-92ca-82e08bac7cf5.jpg" alt="banner says Arslan Ali - Computer Scientist, Data Analysts, Problem Solver along with cartoon illustration">


I'm uploading this project for hands on pactice of upload the project on pypi. I learning this from the Udamey course on the foundation of AWS Machine Learning course. This course is a part of the nano degree by Udamey.


## Find me on:
- <a href=https://www.linkedin.com/in/arslanali>LinkdIn</a>
- <a href=https://www.kaggle.com/arslanali5432>Kaggle</a>
